@@ -22,7 +22,7 @@ except ImportError:
     pass
 
 
-__version__ = "0.3.0"
+__version__ = "0.5.0"
 __repo__ = "https://github.com/jposada202020/MicroPython_UPLOT.git"
 
 
@@ -451,7 +451,7 @@ class PLOT:
                 )
                 start = start - self._grid_espace - self._grid_lenght
 
-    def _writeplainpbm(self, file: str = "newfile.pbm"):
+    def _writeplainpbm(self, file: str = "newfile.pbm") -> None:
         """
         Function to write a plain pbm file
         adapted from https://github.com/orgs/micropython/discussions/10785
@@ -466,7 +466,9 @@ class PLOT:
                 file_write.write("\n")
             file_write.close()
 
-    def _savingppm(self, filename: str = "picture.ppm", width=480, height=320):
+    def _savingppm(
+        self, filename: str = "picture.ppm", width: int = 480, height: int = 320
+    ) -> None:
         """
         Function to save the screen as a ppm file
         Adapted from https://gist.github.com/nicholasRutherford/c95a55239e03ba99bab3
@@ -483,11 +485,17 @@ class PLOT:
             self._color0,
             self._color2,
             self._color1,
-            (0, 255, 0),
-            (0, 255, 255),
-            (99, 0, 99),
-            (0, 94, 153),
-            (0, 167, 109),
+            (255, 0, 0),
+            (237, 0, 86),
+            (218, 0, 105),
+            (199, 0, 124),
+            (181, 0, 142),
+            (162, 0, 161),
+            (143, 0, 180),
+            (125, 0, 198),
+            (106, 0, 217),
+            (87, 0, 236),
+            (68, 0, 255),
         ]
 
         # Header values for the file
